@@ -1,26 +1,29 @@
 """ Test comments and likes """
 
 import datetime
+from zoneinfo import ZoneInfo
 
 import pytest
 
 import osxphotos
 from osxphotos import CommentInfo, LikeInfo
 
-from .conftest import set_timezone
-
 PHOTOS_DB = "tests/Test-Cloud-10.15.6.photoslibrary"
 
 COMMENT_UUID_DICT = {
     "4AD7C8EF-2991-4519-9D3A-7F44A6F031BE": [
         CommentInfo(
-            datetime=datetime.datetime(2020, 9, 18, 10, 28, 41, 552000),
+            datetime=datetime.datetime(
+                2020, 9, 18, 10, 28, 41, 552000, tzinfo=ZoneInfo("America/Los_Angeles")
+            ),
             user="Rhet Turnbull",
             ismine=False,
             text="Nice photo!",
         ),
         CommentInfo(
-            datetime=datetime.datetime(2020, 9, 19, 22, 52, 20, 12014),
+            datetime=datetime.datetime(
+                2020, 9, 19, 22, 52, 20, 12014, tzinfo=ZoneInfo("America/Los_Angeles")
+            ),
             user=None,
             ismine=True,
             text="Wish I was back here!",
@@ -29,7 +32,9 @@ COMMENT_UUID_DICT = {
     "CCBE0EB9-AE9F-4479-BFFD-107042C75227": [],
     "4E4944A0-3E5C-4028-9600-A8709F2FA1DB": [
         CommentInfo(
-            datetime=datetime.datetime(2020, 9, 19, 22, 54, 12, 947978),
+            datetime=datetime.datetime(
+                2020, 9, 19, 22, 54, 12, 947978, tzinfo=ZoneInfo("America/Los_Angeles")
+            ),
             user=None,
             ismine=True,
             text="Nice trophy",
@@ -40,7 +45,9 @@ COMMENT_UUID_DICT = {
 LIKE_UUID_DICT = {
     "4AD7C8EF-2991-4519-9D3A-7F44A6F031BE": [
         LikeInfo(
-            datetime=datetime.datetime(2020, 9, 18, 10, 28, 43, 335000),
+            datetime=datetime.datetime(
+                2020, 9, 18, 10, 28, 43, 335000, tzinfo=ZoneInfo("America/Los_Angeles")
+            ),
             user="Rhet Turnbull",
             ismine=False,
         )
@@ -48,7 +55,9 @@ LIKE_UUID_DICT = {
     "CCBE0EB9-AE9F-4479-BFFD-107042C75227": [],
     "65BADBD7-A50C-4956-96BA-1BB61155DA17": [
         LikeInfo(
-            datetime=datetime.datetime(2020, 9, 18, 10, 28, 52, 570000),
+            datetime=datetime.datetime(
+                2020, 9, 18, 10, 28, 52, 570000, tzinfo=ZoneInfo("America/Los_Angeles")
+            ),
             user="Rhet Turnbull",
             ismine=False,
         )
@@ -57,7 +66,9 @@ LIKE_UUID_DICT = {
 
 COMMENT_UUID_ASDICT = {
     "4E4944A0-3E5C-4028-9600-A8709F2FA1DB": {
-        "datetime": datetime.datetime(2020, 9, 19, 22, 54, 12, 947978),
+        "datetime": datetime.datetime(
+            2020, 9, 19, 22, 54, 12, 947978, tzinfo=ZoneInfo("America/Los_Angeles")
+        ),
         "user": None,
         "ismine": True,
         "text": "Nice trophy",
@@ -66,19 +77,15 @@ COMMENT_UUID_ASDICT = {
 
 LIKE_UUID_ASDICT = {
     "65BADBD7-A50C-4956-96BA-1BB61155DA17": {
-        "datetime": datetime.datetime(2020, 9, 18, 10, 28, 52, 570000),
+        "datetime": datetime.datetime(
+            2020, 9, 18, 10, 28, 52, 570000, tzinfo=ZoneInfo("America/Los_Angeles")
+        ),
         "user": "Rhet Turnbull",
         "ismine": False,
     }
 }
 
 
-@pytest.fixture(scope="module", autouse=True)
-def set_timezone_pacific():
-    with set_timezone("US/Pacific"):
-        yield
-
-
 @pytest.fixture(scope="module")
 def photosdb():
     return osxphotos.PhotosDB(dbfile=PHOTOS_DB)
